function cp = get_cost_params(om, name)
%GET_COST_PARAMS  Returns the cost parameter struct for user-defined costs.
%   CP = GET_COST_PARAMS(OM)
%   CP = GET_COST_PARAMS(OM, NAME)
%
%   Requires calling BUILD_COST_PARAMS first to build the full set of
%   parameters. Returns the full cost parameter struct for all user-defined
%   costs that incorporates all of the named cost sets added via ADD_COSTS,
%   or, if a name is provided it returns the cost struct corresponding to
%   the named set of cost rows (N still has full number of columns).
%
%   The cost parameters are returned in a struct with the following fields:
%       N      - nw x nx sparse matrix
%       Cw     - nw x 1 vector
%       H      - nw x nw sparse matrix (optional, all zeros by default)
%       dd, mm - nw x 1 vectors (optional, all ones by default)
%       rh, kk - nw x 1 vectors (optional, all zeros by default)
%
%   See also OPF_MODEL, ADD_COST, BUILD_COST_PARAMS, COMPUTE_COST.

%   MATPOWER
%   $Id: get_cost_params.m,v 1.5 2010/03/10 18:08:15 ray Exp $
%   by Ray Zimmerman, PSERC Cornell
%   Copyright (c) 2008-2010 by Power System Engineering Research Center (PSERC)
%   See http://www.pserc.cornell.edu/matpower/ for more info.

if ~isfield(om.cost, 'params')
    error('@opf_model/get_cost_params: must call build_cost_params first');
end

cp = om.cost.params;

if nargin > 1
    if getN(om, 'cost', name)
        idx = om.cost.idx.i1.(name):om.cost.idx.iN.(name);
        cp.N  = cp.N(idx,:);
        cp.Cw = cp.Cw(idx);
        cp.H  = cp.H(idx,:);
        cp.dd = cp.dd(idx);
        cp.rh = cp.rh(idx);
        cp.kk = cp.kk(idx);
        cp.mm = cp.mm(idx);
    end
end
